==> qcad-3.32.4.0-1-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation type="unfinished">null</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation type="unfinished">null</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>自訂</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>網格</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation type="unfinished">null</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation type="unfinished">null</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation type="unfinished">null</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation type="unfinished">null</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation type="unfinished">null</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation type="unfinished">null</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation type="unfinished">null</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation type="unfinished">null</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation type="unfinished">null</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation type="unfinished">null</translation>
    </message>
</context>
</TS>

==> qcad-3.32.4.4-3-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation>垂直/水平</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation>返回</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>自訂</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>網格</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>端點</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>在實體上</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>垂直</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>切線</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>中心</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>中點</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>交點</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>參考</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation>距離</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>無效</translation>
    </message>
</context>
</TS>
